@@ -4,7 +4,7 @@ use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 use Carp;
 use 5.005;
-our $VERSION = '1.67';
+our $VERSION = '1.68';
 
 require Exporter;
 
@@ -123,7 +123,6 @@ sub autoformat  # ($text, %args)
         $toSTDOUT = !defined wantarray();
     }
 
-    return unless length $text;
     return $text unless $text =~ /\S/;
 
     $args{right}   = $default_margin unless exists $args{right};
@@ -878,7 +877,7 @@ Text::Autoformat - Automatic text wrapping and reformatting
 
 =head1 VERSION
 
-This document describes version 1.669006 of Text::Autoformat
+This document describes version 1.68 of Text::Autoformat
 
 =head1 SYNOPSIS
 
@@ -1239,14 +1238,14 @@ format lines such as:
 
 specify:
 
-    autoformat($text, { quoter =E<gt> qr{//})
+    autoformat($text, { quoter =E<gt> qr{//} })
 
 Instead of completely replacing the existing set of quoters, you can
 I<extend> them by specifying a pattern that includes the metasequence
 C<< <QUOTER> >>, which is then replaced by the module's standard pattern
 for quoters. So, for example, to add C<//> to the set of existing quoters:
 
-    autoformat($text, { quoter =E<gt> qr{//|<QUOTER>})
+    autoformat($text, { quoter =E<gt> qr{//|<QUOTER>} })
 
 
 Block quotations present a different challenge. A typical formatter
